Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWillian Padovani Germano <wpgermano@gmail.com>2003-06-28 11:38:21 +0400
committerWillian Padovani Germano <wpgermano@gmail.com>2003-06-28 11:38:21 +0400
commiteaf1cdd3836aa425e3dc6f1a11d4556bd7e3e876 (patch)
treefe8e701c3e3daa38749b78238858edbbbfea1f91 /source/blender/python/api2_2x/constant.h
parent569a32a2ea3a1992eaeaa5dc0256c48e8a053fbd (diff)
- More renaming all around to follow our conventions
- Implemented partially Blender.Sys - Worked on issues related to sys, path - Took away most "debug" printfs
Diffstat (limited to 'source/blender/python/api2_2x/constant.h')
-rw-r--r--source/blender/python/api2_2x/constant.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/source/blender/python/api2_2x/constant.h b/source/blender/python/api2_2x/constant.h
index 8d70c5051a0..3f95f11dd2b 100644
--- a/source/blender/python/api2_2x/constant.h
+++ b/source/blender/python/api2_2x/constant.h
@@ -46,17 +46,17 @@
PyObject *M_constant_New (void);
/*****************************************************************************/
/* Python C_constant structure definition: */
/*****************************************************************************/
typedef struct {
PyObject_HEAD
PyObject *dict;
-} C_constant;
+} BPy_constant;
/*****************************************************************************/
/* Python C_constant methods declarations: */
/*****************************************************************************/
-int constant_insert(C_constant *self, char *name, PyObject *value);
+int constant_insert(BPy_constant *self, char *name, PyObject *value);
#endif /* EXPP_constant_H */
@@ -46,17 +46,17 @@
PyObject *M_constant_New (void);
/*****************************************************************************/
-/* Python C_constant structure definition: */
+/* Python BPy_constant structure definition: */
/*****************************************************************************/
typedef struct {
@@ -46,17 +46,17 @@
/*****************************************************************************/
-/* Python C_constant methods declarations: */
+/* Python BPy_constant methods declarations: */
/*****************************************************************************/